# Release History

## 1.1.4 (08/15/2022)

- Bug fix for container client

## 1.1.3 (08/12/2022)

- Copy files between any location within the same storage account

- Move files (cut and paste) between any location within the same storage account

- Copy a file from a URL to a path inside the storage account

- Generate SAS URL for a file inside the storage account

## 1.1.2 (08/08/2022)

- Official Documentation site

## 1.1.1 (08/05/2022)

- Standardized documentation

- Updated azure-storage-blob dependency to v12.13.1

## 1.1.0 (08/05/2022)

- Asynchronous and synchronous clients available

- Complete API documentation

- Test suite for versioning, async client and sync client

## 1.0.1 (08/04/2022)

- Naming conventions bug fix

## 1.0.0 (08/02/2022)

- Initial Release

- Configured, CHANGELOG, LICENSE, and MANIFEST

- Connect to cloud-based or IoT Edge-based storage accounts

- Connect via connection string or storage account key
